@@ -23,6 +23,7 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
@@ -44,10 +45,12 @@ typedef struct
 } CheeseThumbViewClass;
 
 
-GType	           cheese_thumb_view_get_type (void);
+GType	         cheese_thumb_view_get_type (void);
 GtkWidget       *cheese_thumb_view_new ();
 GList           *cheese_thumb_view_get_selected_images_list (CheeseThumbView *thumb_view);
 char            *cheese_thumb_view_get_selected_image (CheeseThumbView *thumb_view);
+guint            cheese_thumb_view_get_n_selected (CheeseThumbView *thumbview);
+void             cheese_thumb_view_remove_item (CheeseThumbView *thumb_view, GFile *file);
 
 G_END_DECLS
 
